﻿Imports Sections
Imports SteelConnectionsEC3

Public Class Form1

    Private Sub Button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button1.Click
        'Create a connection object
        Dim con As New BeamColumnPlate1Connection

        'Create a SingleBoltedPlate object
        Dim Plate As New SingleBoltedPlate()
        Plate.b = 200
        Plate.h = 300
        Plate.ex1 = 50
        Plate.ex2 = 50
        Plate.ey1 = 100
        Plate.ey2 = 100
        Plate.BoltColumns = 2
        Plate.BoltRows = 2
        Plate.Steel = New SteelGrade(SteelGrade.Grade.S235)
        Plate.t = 10
        Plate.Bolts = New Bolts(Bolts.Type.M16, Bolts.Grade.g4_8)

        'Set the con.Plate variable equal to the created SingleBoltedPlate object
        con.Plate = Plate

        'Weld thickness between plate and column equal 5 mm
        con.a = 5

        'Connection is implemented about the major axis of the column
        con.AboutColumnMajorAxis = True

        'Set the steel grade of the beam
        con.BeamSteel = New SteelGrade(SteelGrade.Grade.S235)

        'Set beam section
        con.Beam = New HSection(False, "", 360, 160, 6, 5, 9)
        con.Beam.CalculateAllData(78.5, 1)

        'Set column section
        con.Column = New HSection(False, "", 300, 200, 10, 8, 21)
        con.Column.CalculateAllData(78.5, 1)

        'There is a 2-side-weld, so this property is set to true
        con.TwoSideWeld = False

        'Add a load case
        con.LoadCases.Add(New LoadCase("", 0, 50, 0))

        'Get input warnings
        Dim InputWarnings As BeamColumnPlate1ConnectionInputWarnings = con.GetInputWarnings()

        'Finally calculate the connection
        con.Calculate()

        'Design results are stored in con.Results list
        Dim Results As BeamColumnPlate1ConnectionResults = con.Results(0)
    End Sub

    Private Sub Button2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button2.Click
        'Create a connection object
        Dim con As New BeamColumnAngleConnection

        'Create a SingleBoltedPlate object	
        Dim Plate As New SingleBoltedPlate()
        Plate.b = 200
        Plate.h = 300
        Plate.ex1 = 20
        Plate.ex2 = 20
        Plate.ey1 = 20
        Plate.ey2 = 20
        Plate.BoltColumns = 2
        Plate.BoltRows = 2
        Plate.Steel = New SteelGrade(SteelGrade.Grade.S235)
        Plate.t = 10
        Plate.Bolts = New Bolts(Bolts.Type.M16, Bolts.Grade.g4_8)

        'Left connection exists
        con.LeftConnectionAlso = False

        'Set the PlateOnBeamRight and PlateOnBeamLeft properties of the connection
        con.PlateOnBeamRight = Plate
        con.PlateOnColumnRight = Plate

        'Set the weld thickness between the right beam and the cleat
        con.aRight = 5

        'Connection is implemented about the column major axis
        con.AboutCoumnMajorAxis = True


        'Set beam section and steel grade
        con.BeamSteel = New SteelGrade(SteelGrade.Grade.S235)
        con.BeamRight = New HSection(False, "", 200, 160, 6, 5, 9)
        con.BeamRight.CalculateAllData(78.5, 1)

        'Set column section
        con.Column = New HSection(False, "", 300, 200, 10, 8, 21)
        con.Column.CalculateAllData(78.5, 1)

        'Welded connection between right beam and cleat
        con.WeldedOnBeamRight = True

        'There is only one angle for the right and the left connection (not a double angle)
        con.OnlyOneAnglePerConnection = True

        'Add a load case
        con.LoadCasesRight.Add(New LoadCase("", 0, 50, 0))

        'Get input warnings
        Dim InputWarnings As BeamColumnAngleConnectionInputWarnings = con.GetInputWarnings()

        'Finally calculate the connection
        con.Calculate()

        'Design results are stored in con.Results list
        Dim Results As BeamColumnAngleConnectionResults = con.Results(0)
    End Sub

    Private Sub Button3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button3.Click
        'Create a connection object
        Dim con As New BeamSplices1Connection

        'Create a SingleBoltedPlate object that will represent the WebHalfPlate object of the connection
        Dim WebHalfPlate As New SingleBoltedPlate()
        WebHalfPlate.b = 200
        WebHalfPlate.h = 280
        WebHalfPlate.ex1 = 45
        WebHalfPlate.ex2 = 45
        WebHalfPlate.ey1 = 50
        WebHalfPlate.ey2 = 50
        WebHalfPlate.BoltColumns = 2
        WebHalfPlate.BoltRows = 3
        WebHalfPlate.Steel = New SteelGrade(SteelGrade.Grade.S235)
        WebHalfPlate.t = 8
        WebHalfPlate.Bolts = New Bolts(Bolts.Type.M16, Bolts.Grade.g4_6)

        'Assign the created object to the corresponding connection object
        con.WebHalfPlate = WebHalfPlate

        'Create a SingleBoltedPlate object that will represent the FlangeHalfPlate object of the connection
        Dim FlangeHalfPlate As New SingleBoltedPlate()
        FlangeHalfPlate.b = 240
        FlangeHalfPlate.h = 160
        FlangeHalfPlate.ex1 = 45
        FlangeHalfPlate.ex2 = 45
        FlangeHalfPlate.ey1 = 45
        FlangeHalfPlate.ey2 = 45
        FlangeHalfPlate.BoltColumns = 3
        FlangeHalfPlate.BoltRows = 2
        FlangeHalfPlate.Steel = New SteelGrade(SteelGrade.Grade.S235)
        FlangeHalfPlate.t = 20
        FlangeHalfPlate.Bolts = New Bolts(Bolts.Type.M20, Bolts.Grade.g4_6)

        'Assign the created object to the corresponding connection object
        con.FlangeHalfPlate = FlangeHalfPlate

        'Left connection is welded
        con.WeldedLeftConnection = True

        'Weld thickness between member flange and flange plate for right connection (which is welded)
        con.afl = 6
        'Weld thickness between member web and web plate for right connection (which is welded)
        con.aw = 4

        'Gap between connected members equal to 10 mm
        con.gap = 10

        'Set beam section and steel grade
        con.Beam = New HSection(False, "", 400, 180, 13.5, 8.6, 21)
        con.Beam.CalculateAllData(78.5, 1)
        con.BeamSteel = New SteelGrade(SteelGrade.Grade.S235)

        'Add a load case
        con.LoadCases.Add(New LoadCase("", 0, 60.75, 157950)) 'WARNING: kN, mm units, so th moment is 157950 kNmm = 157.95 kNm

        'Get input warnings
        Dim InputWarnings As BeamSplices1ConnectionInputWarnings = con.GetInputWarnings

        'Finally calculate the connection
        con.Calculate()

        'Design results are stored in con.Results list
        Dim results As BeamSplices1ConnectionResults = con.Results(0)
    End Sub

    Private Sub Button4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button4.Click
        'Create a connection object
        Dim con As New BeamColumnEndplateConnection

        'No left connection
        con.LeftConnectionAlso = False

        'Set right beam section and steel grade
        con.BeamRight = New HSection(False, "", 400, 180, 13.5, 8.6, 21)
        con.BeamRight.CalculateAllData(78.5, 1)
        con.RightBeamSteel = New SteelGrade(SteelGrade.Grade.S235)

        'Set column section and steel grade
        con.Column = New HSection(False, "", 390, 300, 19, 11, 27)
        con.Column.CalculateAllData(78.5, 1)
        con.ColumnSteel = New SteelGrade(SteelGrade.Grade.S235)

        'Set weld thickness between right beam flange and endplate
        con.af_beamRight = 6

        'Set weld thickness between right beam web and endplate
        con.aw_beamRight = 3

        'Supplementary column web plates are not used
        con.NrOfSupplementaryWebPlates = 0

        'Create an BoltedEndPlate object
        Dim endplate As New BoltedEndPlate
        With endplate
            .h = 520
            .b = 240
            .t = 25
            .Steel = New SteelGrade(SteelGrade.Grade.S235)
            .Bolts = New Bolts(Bolts.Type.M24, Bolts.Grade.g10_9)
            .ex = 60
            .ey1 = 0
            .ey2 = 90
            .ey3 = 115
            .ey4 = 45
            .h_over = 95
            .RowAbove = True
            .RowBelow = False
            .RowsInside = 2
        End With

        'Assign it to the corresponding connection object
        con.PlateRight = endplate

        'Add a load case (for the right connection)
        con.LoadCasesRightBeam.Add(New LoadCase("", 0, 50, 10000)) 'kN, mm units!

        'Add a load case for the internal forces acting at the column because of above story loads
        con.LoadCasesResultantColumn.Add(New LoadCase("", 100, 30, 10000)) 'kN, mm units!

        'Set that the column will be extended 95 mm above the upper beam flange
        con.ColumnExtensionOverRightBeam = 95

        'Column web stiffeners are used
        con.UseOfColumnWebStiffeners = True

        'Distance between right beam flange and upper column web stiffener
        con.ds_over_rightBeamFlange = 0

        'Distance between column web stiffeners
        con.ds = 500

        'Get input warnings
        Dim InputWarnings As BeamColumnEndplateConnectionInputWarnings = con.GetInputWarnings()

        'Finally calculate the connection
        con.Calculate()

        'Design results are stored in con.Results list
        Dim Results As BeamColumnEndplateConnectionResults = con.Results(0)
    End Sub

    Private Sub Button5_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button5.Click
        'Create a connection object
        Dim con As New ColumnBaseplateConnection

        'Set corresponding footing dimensions
        con.af = 3000
        con.bf = 3000
        con.hf = 1400

        'Set weld thickness between column flange and base plate
        con.afl = 10

        'Set weld thickness between column web and base plate
        con.aw = 8

        'Set corresponding dimensions for the base plate placement on the footing
        con.c1 = 1000
        con.c2 = 1000

        'Set column section and grade
        con.Column = New HSection(False, "", 300, 300, 19, 11, 27)
        con.Column.CalculateAllData(78.5, 1)
        con.ColumnSteel = New SteelGrade(SteelGrade.Grade.S275)

        'Concrete compressive characteristic stress strength
        con.fck = 0.03 'in kN/mm^2 units!!

        'Concrete modulus of elasticity
        con.Ec = 30 'in kN/mm^2 units!!

        'Set grout thickness
        con.grout_t = 30

        'Add a load case
        con.LoadCases.Add(New LoadCase("", 1000, 70, 80000)) 'kN, mm units!!

        'Stiffeners thickness
        con.tst = 10

        'Create a BoltedBasePlate object
        Dim plate As New BoltedBasePlate
        plate.h = 500
        plate.b = 500
        plate.ThereAreRowsOutside = True
        plate.RowsInside = 0
        plate.Bolts = New Bolts(Bolts.Type.M24, Bolts.Grade.g4_6)
        plate.ex = 150
        plate.ey1 = 45
        plate.ey2 = 0
        plate.Steel = New SteelGrade(SteelGrade.Grade.S275)
        plate.t = 30

        'Set it to the corresponding connection object
        con.Plate = plate

        'Use of stiffeners
        con.UseOfStiffeners = True

        'Set stiffeners heigth
        con.hst = 200

        'Set weld thickness between stiffeners and column
        con.ast_col = 5

        'Set weld thickness between stiffeners and base plate
        con.ast_pl = 5

        'Get input warnings
        Dim InputWarnings As ColumnBaseplateConnectionInputWarnings = con.GetInputWarnings()

        'Finally calculate the connection
        con.Calculate()

        'Design results are stored in con.Results list
        Dim Results As ColumnBaseplateConnectionResults = con.Results(0)
    End Sub

    Private Sub Button6_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button6.Click
        'In this example, the Type 1 of the CHS chord connection will be examinded

        'Create a connection object
        Dim con As New CHSChordConnection

        'Create a chord object
        con.Chord = New CHS("Chord", 200, 7)
        con.Chord.CalculateAllData(78.5, 1)
        con.ChordSteel = New SteelGrade(SteelGrade.Grade.S235)

        'Set chord internal forces
        con.NEd0 = 10
        con.VEd0 = 30
        con.MEd0 = 5000

        'Create a brace object
        Dim Brace As New CHS("Brace", 130, 4)
        Brace.CalculateAllData(78.5, 1)

        'Check if resistance criteria are met
        Dim ConnectionIsOK As Boolean = con.AxialResistance_Type1(Brace, 30, 15, New SteelGrade(SteelGrade.Grade.S235))

        'Check if the geometry is within the range of validity of Eurocode 3
        Dim GeometryIsOK As Boolean = con.GeometryRangeOfValidity_OK
    End Sub
End Class
